import { signal, computed } from '@preact/signals-react';

function get(object, path, index = 0) {
    const key = path[index];
    if (key === undefined) return '';
    const val = object[key];
    if (val === undefined) return '';
    if (typeof val === 'string') return val;
    if (typeof val === 'object' && val !== null) {
        return get(Object(val), path, index + 1);
    }
    return '';
}
function replace(str, obj) {
    return str.replace(/{(.*?)}/g, (_, key)=>obj[key]);
}

function createInstance(locales, initialLanguage) {
    const language = signal(initialLanguage);
    const dictionary = computed(()=>locales[language.value]);
    const avaliableLanguages = computed(()=>Object.keys(locales));
    const setLanguage = (_language)=>{
        language.value = _language;
    };
    function t(key, replaceStrings) {
        if (!dictionary) return '';
        const path = String(key).split('.');
        const value = get(dictionary.value, path);
        if (replaceStrings) return replace(value, replaceStrings);
        return value;
    }
    return {
        t,
        language: language.value,
        avaliableLanguages: avaliableLanguages.value,
        setLanguage
    };
}

export { createInstance };
//# sourceMappingURL=index.js.map
